@@ -1,6 +1,10 @@
 from django.conf import settings
 
 
+def show_notice(request):
+    return request.user.is_authenticated or getattr(settings, 'ENVIRONMENT_SHOW_TO_UNAUTHENTICATED', True)
+
+
 def from_settings(request):
     return {
         'ENVIRONMENT_NAME': getattr(settings, 'ENVIRONMENT_NAME', None),
@@ -9,4 +13,6 @@ def from_settings(request):
         'ENVIRONMENT_ADMIN_SELECTOR': getattr(
             settings, 'ENVIRONMENT_ADMIN_SELECTOR', 'body'),
         'ENVIRONMENT_FLOAT': getattr(settings, 'ENVIRONMENT_FLOAT', False),
+        'show_notice': show_notice(request),
+
     }
